package pickstatistics;

import cvarg.seismic.earthworm.messages.PickSCNL;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FilenameFilter;
import java.text.NumberFormat;
import java.util.Locale;
import java.util.Vector;
import javax.swing.table.AbstractTableModel;

public class Main {

    public static Vector<PickCounter> pickers = new Vector<PickCounter>(); /* Vector to store pick messages */

    public static void main(String[] args) {
        /* Search for all files in the current folder */
        System.out.println("Processing files in the current folder.");
        String[] pickFileNames = new File(".").list(new PickFileFilter());
        if (pickFileNames == null) {
            System.out.println("Found no files.");
            System.exit(1);
        }
        /* Cycle to process each file */
        for (int i = 0; i < pickFileNames.length; i++) {
            System.out.println("Processing file: " + pickFileNames[i]);
            /* Open potential pick file */
            try {
                BufferedReader Finput = new BufferedReader(new FileReader(pickFileNames[i]));
                String line;
                while ((line = Finput.readLine()) != null) {
                    try {
                        /* Try to read pick message */
                        PickSCNL msg = new PickSCNL(line);
                        /* Add pick message to counter */
                        PickCounter.addPicker(msg, pickers);
                    } catch (Exception e) {
                        /* This is not a pick message, discard it */
                        System.err.println("Error parsing pick message: " + line);
                    }
                }
            } catch (Exception e) {
                /* Something wrong with reading this file */
                System.err.println(e);
            }
        }


        /* Start GUI */
        new PickStatistics().setVisible(true);
    }

    /*
     * Method to produce the table model
     */
    public static AbstractTableModel getTableModel() {
        Object[][] data = new Object[pickers.size()][2]; /* Store data for table */
        /* Define number format for presentation */
        NumberFormat nf = NumberFormat.getInstance(Locale.US);
        nf.setMaximumFractionDigits(1);
        /* Store data from pickers into data for table */
        for (int i = 0; i < pickers.size(); i++) {
            data[i][0] = pickers.elementAt(i).Station + " " + pickers.elementAt(i).Channel;
            //data[i][1] = nf.format(pickers.elementAt(i).pickAverage(3600000));
            data[i][1] = pickers.elementAt(i).pickAverage(3600000);
        }
        String[] names = new String[]{"Station", "Average pick count"};
        return new PickersTableModel(data, names);
    }

    static class PickFileFilter implements FilenameFilter {

        public boolean accept(File dir, String name) {
            //return name.startsWith("picks."); //Select only files from pick recorder
            return new File(name).isFile(); //Select all files
        }
    }
}
